# Utils

General utilities complimenting and expanding on standard python.

# Setup & Install

```
pip install utils-nuuuwan
```

# Release History
See also [Older Releases](OLDER_RELEASES.md) and [Wish-list](WISHLIST.md)

## 1.0.21
* Added dict_set and dict_get to *ds*

## 1.0.22
* Added *plotx* (Various helpers for MatPlotLib)

## 1.0.23
* Make parse_int and parse_float more general
* Added dict_list_get_values_for_key
* Added get_date
* Added logging to twitter

## 1.0.24
* [2021-07-26 08:38PM] Extend timeout in www.read
* [2021-07-26 08:45PM] release 1.0.24

## 1.0.25
* [2021-07-27 06:25AM] Update setup.py
* [2021-07-29 09:25AM] Added char count to Tweet text is too long
* [2021-07-29 09:29AM] Tweeting Tools
* [2021-07-29 10:08AM] Test python-repo-action
* [2021-07-29 10:49AM] Use nuuuwan/python-repo-test
* [2021-07-29 10:54AM] use-nuuuwan-python-repo-test change to v1
* [2021-07-29 11:11AM] Update pypi-deploy
* [2021-07-29 03:19PM] Update setup.py version format
* [2021-07-29 03:20PM] Update setup.py version format2
